@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
-from django.db import models
 from django.conf import settings
-from django.db.models.signals import pre_save, pre_delete
-from django.utils.translation import ugettext_lazy as _
-from django.core.exceptions import ImproperlyConfigured
 from django.contrib.sites.models import Site
+from django.core.exceptions import ImproperlyConfigured
+from django.db import models
+from django.db.models.signals import pre_delete, pre_save
+from django.utils.encoding import python_2_unicode_compatible
+from django.utils.translation import ugettext_lazy as _
 
 try:
     from django.utils.encoding import force_text
